#######################################################################
# Copyright (c) 2024 ENEO Tecnologia S.L.
# This file is part of redBorder.
# redBorder is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# redBorder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# You should have received a copy of the GNU Affero General Public License
# along with redBorder. If not, see <http://www.gnu.org/licenses/>.
#######################################################################

module IncidentsHelper
  def incidents_uniq_users(incidents, user = current_user) 
    incidents.includes(:users).map { |incident| incident.users.map(&:name) }.flatten.uniq || []
  end

  def incidents_uniq_sources(incidents, user = current_user)
    incidents.pluck(:source).uniq.reject(&:blank?) || []
  end

  def worklog_uniq_types(user = current_user)
    [['Notes','Notes'], ['Incident Changes', 'Incident Changes'], ['Response Actions', 'Response Actions']]
  end

  def worklog_uniq_users(worklog_data, user = current_user)
    worklog_data.pluck(:user).pluck(:name, :id).uniq || []
  end

  def worklog_uniq_orders(user = current_user)
    [['Newest','Newest'], ['Oldest', 'Oldest']]
  end

  def priority_color(priority_name)
    case priority_name.downcase
    when "low"
      "#ffffff"
    when "medium"
      "#ffffff"
    when "high"
      "#ffffff"
    when "critical"
      "#ffffff"
    when "none"
      "#ffffff"
    when "unknow"
      "#ffffff"
    when "info"
      "#ffffff"
    else
      "#ffffff"
    end
  end

  def priority_bgcolor(priority_name)
    case priority_name.downcase
    when "low"
      "#89a54e"
    when "medium"
      "#c69958"
    when "high"
      "#aa4643"
    when "critical"
      "#ff4643"
    when "none"
      "#30BF93"
    when "unknow"
      "#919191"
    when "info"
      "#5eca5e"
    else
      "#000"
    end
  end

  def get_module_name_by_source(source)
    incident_modules = Redborder::Module.registered_modules.select { |_, v| v[:incident_source_name] && v[:incident_source_name] == source }

    incident_modules.first
  end

  def get_incident_filters_link(incident)
    return nil unless incident.source

    mod = get_module_name_by_source(incident.source)

    return nil unless mod

    module_name = mod.first

    hash = {}

    hash[0] = {
        "column" => "incident_uuid",
        "operator" => "is",
        "value" => incident.uuid,
        "enabled" => true
    }

    start_time = incident.created_at - 1.hour
    
    hash[1] = {
      "column" => "start_time",
      "operator" => "is",
      "value" => start_time,
      "enabled" => true
    }
    
    end_time = incident.created_at + 1.day
    hash[2] = {
      "column" => "end_time",
      "operator" => "is",
      "value" => end_time,
      "enabled" => true
    }

    json_string = hash.to_json
    encoded_json = CGI.escape(json_string)
      
    "/#{module_name}/tops?search=#{encoded_json}"
  end

  def get_detection_element_filters_link(element)
    hash = {}

    element[:url_filters].each_with_index do |e, index|
      field = e.first
      value = e.last

      hash[index] = {
        "column" => field,
        "operator" => "is",
        "value" => value,
        "enabled" => true
      }
    end

    json_string = hash.to_json
    encoded_json = CGI.escape(json_string)
    
    "/#{element[:module_name]}/tops?search=#{encoded_json}"
  end
end