#######################################################################
# Copyright (c) 2024 ENEO Tecnologia S.L.
# This file is part of redBorder.
# redBorder is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# redBorder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# You should have received a copy of the GNU Affero General Public License
# along with redBorder. If not, see <http://www.gnu.org/licenses/>.
#######################################################################

module Redborder

  module Jobs

    class MacInventoryJob < Struct.new(:verbose, :user_id)

      include Redborder::Jobs::JobHelper

      def perform

        content = ("Node executing this job: " + `hostname`.chomp! + "\n\n")

        begin

          # get namespaces_uuids
          namespaces_uuids = get_namespaces_uuids
        
          content += `/usr/lib/redborder/scripts/rb_get_inventory.rb #{namespaces_uuids.join(' ')}`

        rescue Exception => e
          content += "#{e.class}: #{e.message}\n"
          e.backtrace.each do |line|
            content += "#{line}\n"
          end
          logit "#{e.class}: #{e.message}" if verbose
        ensure
          StoredDelayedJob.create(job: "MacInventoryJob", user_id: user_id, content: content)
          Delayed::Job.enqueue(Redborder::Jobs::MacInventoryJob.new(user_id, true), priority: 10, run_at: Time.now + 1.hour)
        end

      end

      private 

      #
      # Returns Namespaces uuids
      #
      def get_namespaces_uuids
        Sensor.where(domain_type: Sensor::NAMESPACE).pluck(:uuid)
      end

    end

  end

end